@@ -59,7 +59,11 @@ static const Profiles g_vaProfiles = {
     VAProfileVP9Profile1,
     VAProfileVP9Profile2,
     VAProfileVP9Profile3,
-#if VA_CHECK_VERSION(1,18,0) 
+#if VA_CHECK_VERSION(1,8,0)
+    VAProfileAV1Profile0,
+    VAProfileAV1Profile1,
+#endif
+#if VA_CHECK_VERSION(1,18,0)
     VAProfileH264High10,
 #endif
 };
@@ -110,6 +114,12 @@ static const Profiles g_vaVP9Profiles = {
     VAProfileVP9Profile3,
 };
 
+static const Profiles g_vaAV1Profiles = {
+#if VA_CHECK_VERSION(1,8,0)
+    VAProfileAV1Profile0, VAProfileAV1Profile1,
+#endif
+};
+
 static const Entrypoints g_vaEntrypoints = {
     VAEntrypointVLD,
     VAEntrypointIZZ,
@@ -264,6 +274,9 @@ static const BitMasks g_vaSurfaceMemTypes = {
     VA_SURFACE_ATTRIB_MEM_TYPE_USER_PTR, VA_SURFACE_ATTRIB_MEM_TYPE_KERNEL_DRM,
     VA_SURFACE_ATTRIB_MEM_TYPE_DRM_PRIME,
     VA_SURFACE_ATTRIB_MEM_TYPE_DRM_PRIME_2,
+#if VA_CHECK_VERSION(1, 21, 0)
+    VA_SURFACE_ATTRIB_MEM_TYPE_DRM_PRIME_3,
+#endif
 };
 
 static const std::map<VASurfaceAttribType, const BitMasks&>
